# UltraCart Python SDK

UltraCart REST API Version 2

Note: Every method has a sample for every language.  See https://github.com/UltraCart/sdk_samples

This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 2.0.0
- Package version: 4.1.10
- Build package: org.openapitools.codegen.languages.PythonClientCodegen
For more information, please visit [http://www.ultracart.com/api/](http://www.ultracart.com/api/)

## Requirements.

Python >=3.6

## Installation & Usage
### pip install

```sh
pip install ultracart-rest-sdk
```
(you may need to run `pip` with root permission: `sudo pip install ultracart-rest-sdk`)

Then import the package:
```python
import ultracart
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import ultracart
```

## Getting Started

Here is a sample of the UltraCart Python SDK:

```python
from ultracart.apis import OrderApi
from samples import api_client  # see the sdk_samples github repo

# Create Order API instance
order_api = OrderApi(api_client())

# The expand variable instructs UltraCart how much information to return. The order object is large and
# while it's easily manageable for a single order, when querying thousands of orders, it is useful to reduce
# payload size.
# See www.ultracart.com/api/ for all the expansion fields available (this list below may become stale).
#
# Possible Order Expansions:
# affiliate           affiliate.ledger                    auto_order
# billing             channel_partner                     checkout
# coupon              customer_profile                    digital_order
# edi                 fraud_score                         gift
# gift_certificate    internal                            item
# linked_shipment     marketing                           payment
# payment.transaction quote                               salesforce
# shipping            shipping.tracking_number_details    summary
# taxes

expand = "item,summary,billing,shipping,shipping.tracking_number_details"

# Define order ID
order_id = 'DEMO-0009104390'

# Retrieve order
api_response = order_api.get_order(order_id, expand=expand)

# Check for errors
if api_response.error:
    print(f"Developer Message: {api_response.error.developer_message}")
    print(f"User Message: {api_response.error.user_message}")
    exit()

# Extract order details
order = api_response.order

# Print order details
print(order)
```



# CHANGE LOG
Not every change is committed to every SDK.

| Version | Date | Comments |
| --: | :-: | --- |
| 4.1.10 | 05/06/2025 | conversation - ConversationAgentProfile.user_id added for agent profiles call |
| 4.1.9 | 05/05/2025 | conversations - method to fetch all agent profiles for admin screens |
| 4.1.8 | 04/22/2025 | order property fields for created_by and created_dts |
| 4.1.7 | 04/21/2025 | conversation agent additional fields |
| 4.1.6 | 04/16/2025 | added channel partner order item properties |
| 4.1.5 | 03/28/2025 | added paypal fastlane constants for payments |
| 4.1.4 | 03/07/2025 | updated github readme.md |
| 4.1.3 | 03/07/2025 | updated github readme.md files |
| 4.1.2 | 03/05/2025 | added ChannelPartnerOrder.use_prior_payment_information_from_order_id |
| 4.1.1 | 02/28/2025 | auto order pause method |
| 4.1.0 | 02/21/2025 | ItemApi.getInventorySnapshot had bad nickname causing bad sdk method name |
| 4.0.245 | 02/20/2025 | automation fix |
| 4.0.244 | 02/20/2025 | no change, revving sdk to troubleshoot java deployment automation |
| 4.0.243 | 02/20/2025 | no change, revving sdk to troubleshoot java deployment automation |
| 4.0.242 | 02/18/2025 | small bug fixes for incorrect return types on several methods |
| 4.0.241 | 02/06/2025 | added storefront_host_name to channel partner order object |
| 4.0.240 | 01/09/2025 | fix for broken 4.0.39 due to incorrect query sig on getCustomers |
| 4.0.239 | 01/09/2025 | added emails parameter to customer queries, refundOrder added to Channel partner |
| 4.0.238 | 12/13/2024 | added user and group ids to conversation agent auth object |
| 4.0.237 | 11/11/2024 | added seo properties to item.content object |
| 4.0.236 | 11/07/2024 | Coupon - PercentOffWithItemsQuantityPurchase - added support for tags |
| 4.0.235 | 11/04/2024 | item - new constant for auto order schedule of every 5 months |
| 4.0.234 | 10/24/2024 | storefront page attribute edit method |
| 4.0.233 | 09/18/2024 | order payment constant for PayPal Fastlane |
| 4.0.232 | 08/29/2024 | add hold_for_transmission to item shipping object |
| 4.0.231 | 08/08/2024 | added query_target to OrderApi.getOrdersBatch to allow cache usage |
| 4.0.230 | 06/24/2024 | conversation object cleanup |
| 4.0.229 | 06/14/2024 | pbx menu - add say voice property |
| 4.0.228 | 06/07/2024 | conversation pbx - adjust agent voicemail box uuid fields |
| 4.0.227 | 06/03/2024 | conversationPbxPhoneNumber - fix serialized name for phone number UUID |
| 4.0.226 | 05/31/2024 | ItemApi.getInventorySnapshot method |
| 4.0.225 | 05/30/2024 | add adult sig req. to the merchant item destination markup for items |
| 4.0.224 | 05/29/2024 | added methods getEmailCommseqRateLimiters, resetEmailCommseqRateLimiters |
| 4.0.223 | 05/28/2024 | added property to OrderQuery object to allow querying from cache |
| 4.0.222 | 05/17/2024 | conv.pbx time based config - changed name from default to default_mapping |
| 4.0.221 | 05/16/2024 | OrderPayment - constants for payment method Amazon Pay and Link |
| 4.0.220 | 05/15/2024 | conversation pbx voicemail mailbox indep. voice properties |
| 4.0.219 | 05/15/2024 | conversation pbx - missing fields on agent object |
| 4.0.218 | 05/14/2024 | conversation pbx - allowed value constants on the action |
| 4.0.217 | 05/13/2024 | conversation pbx - bug fix on camelCase property names |
| 4.0.216 | 05/13/2024 | conversation pbx - allow nullable day of week in time range |
| 4.0.215 | 05/08/2024 | added echeck fields to channel partner order import |
| 4.0.214 | 05/02/2024 | conversation - new method to load pbx audio usage |
| 4.0.213 | 05/02/2024 | autoorder - fields to record merge association and tstamp |
| 4.0.212 | 05/01/2024 | getConversationPbxAudioUploadUrl - fix the response obj def |
| 4.0.211 | 04/24/2024 | esp - add fields for external generation on email |
| 4.0.210 | 04/04/2024 | AutoOrder.calculated_next_shipment_dts |
| 4.0.209 | 04/01/2024 | added merchant_id as read-only top level property of AutoOrder object |
| 4.0.208 | 03/26/2024 | WorkflowTask - added assigned_to_user_or_group field |
| 4.0.207 | 03/25/2024 | workflowtask - add global_task_number and object_task_number |
| 4.0.206 | 03/25/2024 | added sales_rep_code to Channel partner order |
| 4.0.205 | 03/19/2024 | workflow task - method to obtain open task count |
| 4.0.204 | 03/19/2024 | workflow task - addl status values, expiration_dts, and system task type |
| 4.0.203 | 03/15/2024 | workflow - getWorkflowAgentWebsocketAuthorization method added |
| 4.0.202 | 03/08/2024 | added getWorkflowTaskTags method |
| 4.0.201 | 02/27/2024 | esp - sms statistic layer |
| 4.0.200 | 02/20/2024 | Add tag support to CouponAmountOffItems, CouponBuyOneGetOneLimit, CouponDiscountItemWithItemPurchase, CouponFreeItemWithItemPurchase, CouponPercentOffItemsWithItemsPurchase |
| 4.0.199 | 01/16/2024 | order query - support searching by custom fields 8 through 10 |
| 4.0.198 | 01/12/2024 | workflow task - add properties array |
| 4.0.197 | 01/10/2024 | workflow tasks - support for searching by tags |
| 4.0.196 | 01/10/2024 | workflow task - add uuids of related tasks and tags |
| 4.0.195 | 01/03/2024 | workflow - add task_context field to task obj |
| 4.0.194 | 12/15/2023 | bug fix on bad docs breaking yaml schema |
| 4.0.193 | 12/12/2023 | webhook - added event ruler property |
| 4.0.192 | 11/21/2023 | coupons - addl support on tiered amount/percent off items |
| 4.0.191 | 11/20/2023 | coupon - add item tag support to percent off items and free shipping |
| 4.0.190 | 11/20/2023 | item.google_product_search.color bugfix for bad length validation: 20 to 100 |
| 4.0.189 | 11/13/2023 | coupon - editor values for item tags |
| 4.0.188 | 11/13/2023 | coupon - percent off items - add support for include/exclude by item tags |
| 4.0.187 | 11/09/2023 | item - new auto order step type: pause until |
| 4.0.186 | 11/06/2023 | customer api - added wishlist methods |
| 4.0.185 | 11/01/2023 | customer - do_no_send_mail flag added |
| 4.0.184 | 10/30/2023 | cart/order fields for health benefit card values in summary expansion objects |
| 4.0.183 | 10/27/2023 | workflow task object model refinement |
| 4.0.182 | 10/23/2023 | workflow tasks api |
| 4.0.181 | 10/23/2023 | workflow tasks api |
| 4.0.180 | 10/16/2023 | CartSettingsPaymentCreditCard - add collect_credit_card_verification_number_minimum |
| 4.0.179 | 09/28/2023 | dw bi - add aggregation constant of none |
| 4.0.178 | 09/22/2023 | dwbi - new option to control order-by of result set |
| 4.0.177 | 09/15/2023 | new item fields for additional barcodes |
| 4.0.176 | 09/12/2023 | added oids to customer properties |
| 4.0.175 | 09/06/2023 | esp condition for survey trigger |
| 4.0.174 | 09/05/2023 | auto order schedule - add intervals for 4 6 and 8 weeks |
| 4.0.173 | 08/31/2023 | new coupon - free item and free shipping with purchase |
| 4.0.172 | 08/16/2023 | added validate_original_order query param to auto order update method |
| 4.0.171 | 08/14/2023 | esp - add require_order_within_last to the settings object |
| 4.0.170 | 08/14/2023 | esp - expose rate limiter values in settings object |
| 4.0.169 | 07/27/2023 | dw bi - add settings to the report and page objects |
| 4.0.168 | 07/19/2023 | dw bi - add data_source_uuid to filter connection obj |
| 4.0.167 | 07/19/2023 | dw bi - add data_source_uuid to page visualization obj |
| 4.0.166 | 07/19/2023 | dw bi - add data_source_uuid to report data source |
| 4.0.165 | 07/03/2023 | chart constant for dw report tool |
| 4.0.164 | 06/23/2023 | gauge constant for page visualization library |
| 4.0.163 | 06/20/2023 | auto order - establishAutoOrderByReferenceOrderId method added |
| 4.0.162 | 06/20/2023 | coupon add allowed values for usable_by and new OncePerNewCustomerForItem flag |
| 4.0.161 | 06/15/2023 | add pickup_dts to order.shipping object |
| 4.0.160 | 06/14/2023 | dw bi: add request_dts on the execute queries request and report data set objects |
| 4.0.159 | 06/09/2023 | distribution center pickup times |
| 4.0.158 | 06/08/2023 | customer profile qb tax exempt reason code field |
| 4.0.157 | 06/06/2023 | auto order add_ons |
| 4.0.156 | 05/25/2023 | added venmo constants for payment type |
| 4.0.155 | 05/18/2023 | dw bi - send back the executed SQL |
| 4.0.154 | 05/04/2023 | item api added methods for items reviews |
| 4.0.153 | 04/28/2023 | item - pricing tier level flag for exempt from min item count |
| 4.0.152 | 04/27/2023 | order - expose dual vaulted identifiers |
| 4.0.151 | 04/24/2023 | internal development - data warehouse |
| 4.0.150 | 04/21/2023 | internal development - data warehouse |
| 4.0.149 | 04/19/2023 | internal development - data warehouse |
| 4.0.148 | 04/19/2023 | internal dev - data warehouse |
| 4.0.147 | 04/17/2023 | OrderPaymentTransaction - expose the transaction id |
| 4.0.146 | 04/11/2023 | missing sezzle payment constant |
| 4.0.145 | 04/10/2023 | data warehouse internal dev |
| 4.0.144 | 03/29/2023 | internal development |
| 4.0.143 | 03/22/2023 | data warehouse internal dev |
| 4.0.142 | 03/22/2023 | dw initial framework |
| 4.0.141 | 03/22/2023 | order api - refundable response added manual_because_multiple_charges boolean field |
| 4.0.140 | 03/21/2023 | order api - new stage named Hold |
| 4.0.139 | 03/14/2023 | order.getOrderEdiDocuments |
| 4.0.138 | 03/01/2023 | convo - add sentiment record to conversation obj |
| 4.0.137 | 02/22/2023 | convo - customer initiated flag on engagement |
| 4.0.136 | 02/20/2023 | refund reasons |
| 4.0.135 | 02/17/2023 | convo api - smsUnsubscribeConversation method |
| 4.0.134 | 02/15/2023 | added auto order sorting by next_shipment_dts |
| 4.0.133 | 02/10/2023 | convo - add storefront_host_name to search request |
| 4.0.132 | 02/07/2023 | convo - new event for when a customer joins a queue |
| 4.0.131 | 02/07/2023 | convo - new event for when a customer joins a queue |
| 4.0.130 | 02/06/2023 | convo - add conversation_arn to ConversationWebsocketMessage |
| 4.0.129 | 02/01/2023 | convo - agent profile get/update methods |
| 4.0.128 | 01/27/2023 | convo - added event_engage_customer property to message |
| 4.0.127 | 01/27/2023 | conversations - getLocationsForEngagement method |
| 4.0.126-RC | 01/26/2023 | typo in ConversationWebsocketMessage |
| 4.0.125-RC | 01/26/2023 | conversation - added message type of engagement prompt |
| 4.0.124-RC | 01/25/2023 | convo event for engage customer |
| 4.0.123-RC | 01/25/2023 | order api method generateInvoice |
| 4.0.122-RC | 01/24/2023 | auto order - cancel minimum and change balance options |
| 4.0.121-RC | 01/23/2023 | conversation - method to fetch single engagement record |
| 4.0.120-RC | 01/19/2023 | added skip_on_rebill field to coupon object |
| 4.0.119-RC | 01/19/2023 | convo - getConversationPermissions added |
| 4.0.118-RC | 01/18/2023 | conversation get dept member list method added |
| 4.0.117-RC | 01/18/2023 | conversation dept members |
| 4.0.116-RC | 01/18/2023 | channel partner ship to pref desc field |
| 4.0.115-RC | 01/17/2023 | changed convo webchat constant |
| 4.0.114-RC | 01/17/2023 | support for checkout item properties |
| 4.0.113-RC | 01/14/2023 | add external_id to the point of sale location object |
| 4.0.112-RC | 01/13/2023 | channel - ops to manage ship to prefs |
| 4.0.111-RC | 01/11/2023 | conversations - adjust search results to return multiple convo summaries |
| 4.0.110-RC | 01/10/2023 | add method to query integration log record by oid |
| 4.0.109-RC | 01/10/2023 | bug fix for typescript enum error due to apost |
| 4.0.108-RC | 01/10/2023 | integration log tracking of associated auto order oids |
| 4.0.107-RC | 01/06/2023 | conversation search response object bug fix |
| 4.0.106-RC | 01/05/2023 | communications - added maximum_enrolled flag on flow object |
| 4.0.105-RC | 01/03/2023 | conversation events for party leave and join |
| 4.0.104-RC | 01/03/2023 | order point of sale details |
| 4.0.103-RC | 12/27/2022 | additional loyalty related coupons |
| 4.0.102-RC | 12/21/2022 | conversation development |
| 4.0.101-RC | 12/20/2022 | conversation engagement update |
| 4.0.100-RC | 12/20/2022 | conversation engagement update |
| 4.0.99-RC | 12/15/2022 | conversation search - added start date filtering |
| 4.0.98-RC | 12/15/2022 | conversation searching |
| 4.0.97-RC | 12/13/2022 | conversations - add email and sms_phone to participant object |
| 4.0.96-RC | 12/09/2022 | conversations - message translation |
| 4.0.95-RC | 12/08/2022 | conversation canned messages |
| 4.0.94-RC | 12/08/2022 | communications - expose the rebuild percentage |
| 4.0.93-RC | 12/06/2022 | convo - add session_start_dts to webchat context, cart - add customer_profile.signup_dts |
| 4.0.92-RC | 12/06/2022 | customer api - expose edi information and editor values |
| 4.0.91-RC | 12/02/2022 | conversations - customer last unresponded dts |
| 4.0.90-RC | 11/30/2022 | conversations - add order and auto order information to webchat context |
| 4.0.89-RC | 11/30/2022 | order item - addl fields for linking kits to kit components |
| 4.0.88-RC | 11/29/2022 | converstation marked convo read method |
| 4.0.87-RC | 11/21/2022 | coupon - addl optional minimums for percent off msrp items coupon |
| 4.0.86-RC | 11/21/2022 | conversation context method |
| 4.0.85-RC | 11/21/2022 | adjusted conversation event model |
| 4.0.84-RC | 11/15/2022 | conversation methods bug fix |
| 4.0.83-RC | 11/15/2022 | conversations - enw events for add coupon and items |
| 4.0.82-RC | 11/15/2022 | order api new method is order refundable |
| 4.0.81-RC | 11/15/2022 | increase order property length to 10k char |
| 4.0.80-RC | 11/14/2022 | conversations - add allowed values for update agent status |
| 4.0.79-RC | 11/09/2022 | conversations - add an enum of event typing |
| 4.0.78-RC | 11/04/2022 | new coupon type percent based on msrp |
| 4.0.77-RC | 10/31/2022 | communication bug fix on dup annonation |
| 4.0.76-RC | 10/31/2022 | communications - addl statistics on EmailStepStat object |
| 4.0.75-RC | 10/26/2022 | esp - methods for sms testing |
| 4.0.74-RC | 10/17/2022 | conversations - add last_interactive_message_dts |
| 4.0.73-RC | 10/07/2022 | bug fix for digital items response |
| 4.0.72-RC | 10/05/2022 | storefront rest file cdn icon urls |
| 4.0.71-RC | 10/04/2022 | bug fix for new storefront file mgr |
| 4.0.70-RC | 09/29/2022 | page_paths search category for search2 method |
| 4.0.69-RC | 09/29/2022 | storefront file mgr calls tweaks |
| 4.0.68-RC | 09/29/2022 | storefront methods for file manager ui |
| 4.0.67-RC | 09/27/2022 | added digital library call for unassociated content |
| 4.0.66-RC | 09/22/2022 | digital item mgmt testing |
| 4.0.65-RC | 09/22/2022 | testing digital file mgmt calls |
| 4.0.64-RC | 09/19/2022 | conversations pagination |
| 4.0.63-RC | 09/13/2022 | storefront comms - postcard tracking |
| 4.0.62-RC | 09/12/2022 | storefront comm - send back reviews.io configured flag on getEmailSettings |
| 4.0.61-RC | 09/07/2022 | sf comms - using aws event ruler for bigquery segmentation validation |
| 4.0.60-RC | 09/02/2022 | customer editor added loyal ledger descriptions |
| 4.0.59-RC | 08/30/2022 | storefront comm fields for sms configuration |
| 4.0.58-RC | 08/26/2022 | postcard address fields for comm sequence testing |
| 4.0.57-RC | 08/22/2022 | exposing individual reviews within item.review object |
| 4.0.56-RC | 08/19/2022 | order api - added cell phone fields for sms |
| 4.0.55-RC | 08/12/2022 | internal code to allow merchant login as customer |
| 4.0.54-RC | 08/11/2022 | fix entry_dts type on gift certificate ledger |
| 4.0.53-RC | 08/10/2022 | conversation event refactoring |
| 4.0.52-RC | 08/05/2022 | conversation adjustments for ES integration |
| 4.0.51-RC | 08/05/2022 | conversations query by medium and stats fixes |
| 4.0.50-RC | 08/03/2022 | conversation summary participants |
| 4.0.49-RC | 08/03/2022 | more conversation events |
| 4.0.48-RC | 08/02/2022 | storefront communication sequence test method |
| 4.0.47-RC | 08/01/2022 | conversation event refinement |
| 4.0.46-RC | 07/29/2022 | conversation development |
| 4.0.45-RC | 07/28/2022 | conversation bug fixes |
| 4.0.44-RC | 07/28/2022 | conversation message upload keys property |
| 4.0.43-RC | 07/26/2022 | conversations - queue statistics |
| 4.0.42-RC | 07/25/2022 | conversation development |
| 4.0.41-RC | 07/25/2022 | conversations bug fixes |
| 4.0.40-RC | 07/25/2022 | conversations - add a websocket message model |
| 4.0.39-RC | 07/21/2022 | conversation response types improvements |
| 4.0.38-RC | 07/21/2022 | conversation bugfix for poor response objects |
| 4.0.37-RC | 07/20/2022 | conversation participant name added |
| 4.0.36-RC | 07/18/2022 | twilio dev |
| 4.0.35-RC | 07/14/2022 | Add channel storefront_oid to the customer activity record |
| 4.0.34-RC | 07/11/2022 | Customer API - mergeCustomer method |
| 4.0.33-RC | 07/05/2022 | docs update |
| 4.0.32-RC | 06/24/2022 | removed unneeded consumes declarations on several api calls (yaml fix) |
| 4.0.31-RC | 06/24/2022 | removed unneeded consumes declarations on several api calls (yaml fix) |
| 4.0.30-RC | 06/24/2022 | removed unneeded consumes declarations on several api calls (yaml fix) |
| 4.0.29-RC | 06/24/2022 | removed unneeded consumes declarations on several api calls (yaml fix) |
| 4.0.28-RC | 06/24/2022 | removed unneeded consumes declarations on several api calls (yaml fix) |
| 4.0.27-RC | 06/24/2022 | removed unneeded consumes declarations on several api calls (yaml fix) |
| 4.0.26-RC | 06/24/2022 | removed unneeded consumes declarations on several api calls (yaml fix) |
| 4.0.25-RC | 06/23/2022 | removed unneeded consumes declarations on several api calls (yaml fix) |
| 4.0.24-RC | 06/23/2022 | automation test |
| 4.0.23-RC | 06/23/2022 | automation test |
| 4.0.22-RC | 06/23/2022 | v4 automation testing - not production ready |
| 4.0.21-RC | 06/22/2022 | v4 automation testing - not production ready |
| 4.0.20-RC | 06/22/2022 | v4 automation testing - not production ready |
| 4.0.19-RC | 06/22/2022 | v4 automation testing - not production ready |
| 4.0.18-RC | 06/22/2022 | v4 automation testing - not production ready |
| 4.0.17-RC | 06/22/2022 | v4 automation testing - not production ready |
| 4.0.16-RC | 06/22/2022 | v4 automation testing - not production ready |
| 4.0.15-RC | 06/22/2022 | v4 automation testing - not production ready |
| 4.0.14-RC | 06/22/2022 | v4 automation testing - not production ready |
| 4.0.13-RC | 06/22/2022 | v4 automation testing - not production ready |
| 4.0.12-RC | 06/22/2022 | v4 automation testing - not production ready |
| 4.0.11-RC | 06/22/2022 | v4 automation testing - not production ready |
| 4.0.10-RC | 06/21/2022 | v4 automation testing - not production ready |
| 4.0.9-RC | 06/21/2022 | v4 automation testing - not production ready |
| 4.0.8-RC | 06/21/2022 | v4 automation testing - not production ready |
| 4.0.7-RC | 06/21/2022 | v4 automation testing - not production ready |
| 4.0.6-RC | 06/21/2022 | v4 automation testing - not production ready |
| 4.0.5 | 06/21/2022 | v4 automation testing - not production ready |
| 4.0.4 | 06/21/2022 | v4 automation testing - not production ready |
| 4.0.3 | 06/21/2022 | v4 automation testing - not production ready |
| 4.0.2 | 06/21/2022 | v4 automation testing - not production ready |
| 4.0.1-RC | 06/21/2022 | ChannelPartnerApi.estimateShipping |
| 3.10.14 | 06/16/2022 | added createEmailSendingDomain2 to support additional MTAs |
| 3.10.13 | 06/16/2022 | renamed latest method to avoid conflict between customer profile search and storefront search |
| 3.10.12 | 06/16/2022 | Customer profile search method to look up tags |
| 3.10.11 | 06/10/2022 | esp segment 3rd party sync add/remove tag fields |
| 3.10.10 | 06/06/2022 | storefront communication options for syncing to third party provider list |
| 3.10.9 | 06/01/2022 | bug fixes for customer profile store credit |
| 3.10.8 | 05/27/2022 | customer store credit |
| 3.10.7 | 05/23/2022 | add internal gift cert to order summary, addl provider info for storefront comm |
| 3.10.6 | 05/23/2022 | add internal gift cert to order summary, addl provider info for storefront comm |
| 3.10.5 | 05/20/2022 | dependabot on java gson version |
| 3.10.4 | 05/20/2022 | dependabot on java gson |
| 3.10.3 | 05/20/2022 | OrderApi.generatePackingSkip calls had wrong return type |
| 3.10.2 | 05/12/2022 | ChannelPartnerApi renamed one of the delete methods |
| 3.10.1 | 05/12/2022 | ChannelPartnerApi added orderId to import response obj |
| 3.10.0 | 05/10/2022 | beta release of ChannelPartnerApi |
| 3.9.8 | 04/26/2022 | OrderApi.duplicateOrder |
| 3.9.7 | 04/25/2022 | integration logs method for zpl to pdf conversion |
| 3.9.6 | 04/25/2022 | storefront communications email magic link setting |
| 3.9.5 | 04/14/2022 | postcard screenshot bug fixes |
| 3.9.4 | 04/13/2022 | Added spf DNS record to the sending domain object |
| 3.9.3 | 04/06/2022 | fix return object on send webhook test method |
| 3.9.2 | 04/04/2022 | user.email field extended and postcard screenshot fields |
| 3.9.1 | 03/03/2022 | javascript sdk package.json bug fix |
| 3.9.0 | 03/03/2022 | removed  ultra_cart_rest_api_v2.d.ts from javascript sdk because typescript sdk exists now |
| 3.8.8 | 03/02/2022 | bug fix for ruby sdk, uri.escape deprecated in 3.x |
| 3.8.7 | 03/02/2022 | bug fix for ruby sdk, uri.escape deprecated in 3.x |
| 3.8.6 | 03/02/2022 | bug fix for ruby sdk, uri.escape deprecated in 3.x |
| 3.8.5 | 02/25/2022 | new coupon for fixed cost shipping method |
| 3.8.2 | 02/16/2022 | create gift certificate method was missing email |
| 3.8.1 | 02/16/2022 | auto order item level pause flag |
| 3.8.0 | 02/16/2022 | gift certificate api (testing) |
| 3.7.38 | 02/15/2022 | gift certificate api (currently in testing) |
| 3.6.38 | 02/07/2022 | Exposed auto order logs |
| 3.6.37 | 02/04/2022 | insurance type for insurance payments |
| 3.6.36 | 12/29/2021 | Mail actual post card flag added to test method |
| 3.6.35 | 12/14/2021 | Add cancel_auto_order option to the accounts receivable retry configuration |
| 3.6.34 | 12/14/2021 | add evening phone E.164 fields to order billing/shipping objects |
| 3.6.33 | 12/13/2021 | automation testing |
| 3.6.32 | 12/10/2021 | testing automation - message 4 |
| 3.6.25 | 12/06/2021 | sdk automation testing.  no changes to actual sdk | 
| 3.6.24 | 11/30/2021 | return items_invalid_for_coupons for CouponResponse object to drive UI warnings | 
| 3.6.23 | 11/29/2021 | Item auto order prohibit cards that expire in months setting. | 
| 3.6.22 | 11/23/2021 | new storefront methods for twilio configuration | 
| 3.6.21 | 11/08/2021 | item shipping distribution center level CostOfGoodsSold | 
| 3.6.20 | 11/05/2021 | additional item auto order step types  | 
| 3.6.19 | 10/05/2021 | item fulfillment add ons  | 
| 3.6.18 | 09/30/2021 | terms if auto order flag added  | 
| 3.6.16 | 09/30/2021 | item exclude from sitemap field  | 
| 3.6.15 | 09/28/2021 | added refund_claim_id to insurance object  | 
| 3.6.14 | 09/21/2021 | configuration api fix.  the echeck test methods were attached to the paper check object  | 
| 3.6.13 | 09/20/2021 | expose EasyPost tracker id if available on shipment tracking details  | 
| 3.6.12 | 09/20/2021 | fix method for getCouponsByQuery to be POST instead of GET since it uses a JSON body  | 
| 3.6.11 | 09/13/2021 | fix for CouponApi, broke due to inadvertent parameter inclusion   | 
| 3.6.10 | 09/09/2021 | added constants for Google Shopping payment method (still in development)  | 
| 3.6.9 | 09/07/2021 | customer profile editor values have new list of state optional countries  | 
| 3.6.8 | 08/31/2021 | coupon query field to allow merchant code and description to be searched  | 
| 3.6.7 | 08/27/2021 | customer profile affiliate information now contains affiliate first and last name | 
| 3.6.6 | 08/26/2021 | configuration api - more field changes for UI | 
| 3.6.5 | 08/25/2021 | configuration api - removed some internal fields from sdk | 
| 3.6.4 | 08/24/2021 | configuration api - new payment method named insurance | 
| 3.6.1 | 08/23/2021 | configuration api - enum problems, also added order.item.tracking_number to support line item tracking numbers | 
| 3.6.0 | 08/19/2021 | coupon api - changed tieredAmountOffItem to support mulitple items | 
| 3.5.3 | 08/18/2021 | configuration api - added credit card rate to UltraCart Payments object | 
| 3.5.1 | 08/11/2021 | email webhook test method | 
| 3.5.0 | 08/11/2021 | RestOrderChannelPartner.store_completed was incorrectly defaulting to true | 
| 3.4.13 | 08/10/2021 | configuration api - changed some field types form string to number | 
| 3.4.12 | 08/10/2021 | email engine - added webhook editor values for internal ui  | 
| 3.4.9 | 08/05/2021 | configuration api - updated annotations for method names | 
| 3.4.8 | 08/04/2021 | configuration api - payments config refactoring | 
| 3.4.7 | 08/04/2021 | esp folders for lists/segments | 
| 3.4.5 | 08/03/2021 | configuration api bug fix for a bad response object on updateRotatingTransactionGateway | 
| 3.4.3 | 08/03/2021 | package tracking - add event_iso_date and event_timezone_id | 
| 3.4.2 | 07/29/2021 | bug fixes for new configuration api | 
| 3.4.1 | 07/29/2021 | bug fixes for new configuration api | 
| 3.4.0 | 07/29/2021 | added new configuration api (not live yet. sdk only works against development presently) | 
| 3.3.2 | 07/16/2021 | sso bug fixes | 
| 3.3.1 | 07/16/2021 | screen recording - event sub text used for assisting in UX rendering | 
| 3.3.0 | 07/16/2021 | new endpoint SingleSignOn | 
| 3.2.15 | 07/13/2021 | storefront communications - added methods to retrieve step dispatch logs | 
| 3.2.14 | 07/12/2021 | fix documentation bug on packing slip methods for order api | 
| 3.2.13 | 07/12/2021 | coupon api - added hideFromCustomer flag | 
| 3.2.12 | 07/09/2021 | new fulfillment and order methods for generation of packing slips | 
| 3.2.11 | 07/08/2021 | screen recording - missing external tracking flag added | 
| 3.2.10 | 07/08/2021 | customer profile - allow drop shipping options | 
| 3.2.9 | 07/07/2021 | screen recording - provide cost per thousand and retention interval | 
| 3.2.8 | 07/06/2021 | intgeration logs - min max log date/time retured in filter values | 
| 3.2.7 | 07/05/2021 | integration logger bug fixes | 
| 3.2.6 | 06/25/2021 | integration log: added logger name | 
| 3.2.2 | 06/24/2021 | integration log file mime type added | 
| 3.2.0 | 06/23/2021 | Changed 4 methods due to naming conflicts revealed through swagger validator.  All internal methods, so impact should be negligible | 
| 3.1.50 | 06/23/2021 | Integrated Logging: returning back streamed files for log requests | 
| 3.1.49 | 06/17/2021 | Integrated Logging: standardize the response object from getIntegrationLog method  | 
| 3.1.47 | 06/16/2021 | Integrated Logging Rest API  | 
| 3.1.46 | 06/14/2021 | Screen recording: server side paginated heat map index with url contains filters, Item: channel partner item mapping unit cost override  | 
| 3.1.44 | 06/02/2021 | new boolean flag on items object to allow sharing of reviews between items   | 
| 3.1.43 | 06/01/2021 | fix item serialized name of item serialized name for channel partner item mappings  | 
| 3.1.42 | 06/01/2021 | added quickbooks accounting codes at the tiered level for tiered coupons  | 
| 3.1.41 | 05/21/2021 | screen recording heatmap methods | 
| 3.1.40 | 05/20/2021 | Order.summary.actual_payment_processing field added | 
| 3.1.39 | 05/19/2021 | full deployment to ensure all language SDKs are up to date | 
| 3.1.37 | 05/18/2021 | removed php sdk dependency on ext-mbstring by generating sdk with polyfill requirement.  sdk is more portable now. | 
| 3.1.35 | 05/14/2021 | screen recording histogram data  | 
| 3.1.34 | 05/12/2021 | screen recording preferred language, last x days filter, referrer domain | 
| 3.1.33 | 05/11/2021 | creen recording filter for affiliate id and email | 
| 3.1.32 | 05/06/2021 | customer profile pending loyalty points  | 
| 3.1.31 | 05/06/2021 | Added email domian field to screen recordings for filtering  | 
| 3.1.30 | 04/27/2021 | OrderApi.processPayment now allows a specific amount to be billed  | 
| 3.1.29 | 04/26/2021 | screen recording language iso code | 
| 3.1.28 | 04/26/2021 | screen recording statistics on the setting object | 
| 3.1.27 | 04/20/2021 | bug fix - annotation misspell on new email campaign property |
| 3.1.26 | 04/20/2021 | StoreFront Connumications - flag to end campaign or flow once purchase happens anywhere |
| 3.1.25 | 04/19/2021 | Screen recording UTM campaign and source fields |
| 3.1.24 | 04/16/2021 | Screen recording aggregations on communications campaign/flows |
| 3.1.22 | 04/09/2021 | Move URL filter values into page level view for screen recordings |
| 3.1.18 | 03/17/2021 | Added order query by ship on date |
| 3.1.17 | 03/17/2021 | New coupon - percent off MSRP item |
| 3.1.16 | 03/16/2021 | screen recording filter page parameter names |
| 3.1.15 | 03/15/2021 | fix response from deleteScreenRecordingSegment that should have been void |
| 3.1.14 | 03/15/2021 | sort screen recordings by favorite flag |
| 3.1.13 | 03/02/2021 | new webhook order_payment_failed |
| 3.1.12 | 02/25/2021 | added screen recording visitor_first_seen property |
| 3.1.11 | 02/24/2021 | Added Screen recording visitor number |
| 3.1.10 | 02/24/2021 | Added Screen recording merchant notes |
| 3.1.9 | 02/24/2021 | Allow coupons to be configured as unique with expiration on cart step within StoreFront Communications |
| 3.1.8 | 02/24/2021 | Add flag: screen recording missing event boolean |
| 3.1.5 | 02/12/2021 | Bug Fix: PHP retry logic missing a closing brace. Also screen recording page view data response refactor |
| 3.1.3 | 02/11/2021 | Bug Fix: wrong return type on CustomerApi.validateEmailVerificationToken |
| 3.1.2 | 02/11/2021 | CustomerApi.getEmailVerificationToken, CustomerApi.validateEmailVerificationToken added to allow for custom email verification.  Also added favorite flag to screen recording object |
| 3.1.1 | 02/10/2021 | CustomerApi.getCustomerByEmail() method added |
| 3.1.0 | 02/10/2021 | Minor revision jump.  Added new convenience methods for simple_key use to all api calls.  Updated docs |
| 3.0.75 | 02/01/2021 | StoreFront Communication plan revision (internal use) |
| 3.0.71 | 01/28/2021 | BugFix: PHP SDK retry logic NPE |
| 3.0.70 | 01/26/2021 | Checkout return URL support |
| 3.0.66 | 01/22/2021 | code library attributes (mostly internal dev) |
| 3.0.65 | 01/22/2021 | Added folder support for email campaigns and flows |
| 3.0.64 | 01/20/2021 | Bug fix on revenue per customer field incorrectly named. |
| 3.0.63 | 01/20/2021 | CouponAPI: bug fixes and new method doesCouponCodeExist |
| 3.0.62 | 01/19/2021 | Added retry ability when rate limit is triggered (PHP SDK only) only) Other sdk to follow. |
| 3.0.60 | 01/14/2021 | Working with Ruby SDK |
| 3.0.57 | 12/17/2020 | CouponAPI: Added Buy one get one free coupon |
| 3.0.53 | 12/14/2020 | StoreFrontAPI: added a duplicate method to load the pricing tiers on the StoreFront |
| 3.0.51 | 12/09/2020 | UserAPI: internal bug preventing proper usage of user group creation |
| 3.0.45 | 12/03/2020 | CouponAPI: added partial searches to getCoupon params, added deleteCoupons method, fixed bugs |
| 3.0.44 | 12/03/2020 | Code library updates, intended for internal use |
| 3.0.43 | 12/02/2020 | Added fields to code library to handle versions of published items |
| 3.0.42 | 12/02/2020 | Added display values to CouponApi.getEditorValues to make type dropdowns easy |
| 3.0.41 | 11/17/2020 | New modify cart step option for StoreFront communications |
| 3.0.39 | 11/12/2020 | Added Customer.tax_codes.taxjar_exemption_type |
| 3.0.38 | 11/09/2020 | Added TaxProviderTaxJar.configuration.send_outside_nexus flag |
| 3.0.37 | 11/06/2020 | Added transactional email screenshots for code library |
| 3.0.36 | 11/03/2020 | Added missing constant for pre-order stage |
| 3.0.34 | 10/26/2020 | UserAPI initial release |
| 3.0.33 | 10/23/2020 | Added library_item_oid to StoreFront Communications email object for upcoming code library |
| 3.0.32 | 10/21/2020 | Added new StoreFrontApi.search method that takes a POST instead of a GET |
| 3.0.31 | 10/16/2020 | more dev work on code library (internal) |
| 3.0.30 | 10/08/2020 | development work on code library (internal), first version of UserAPI.  The UserAPI is not live yet. |
| 3.0.29 | 09/29/2020 | new boolean field on coupon: bug fix |
| 3.0.28 | 09/29/2020 | new boolean field on coupon: free item with purchase of another item |
| 3.0.27 | 09/29/2020 | Refactored the code library applyToStoreFront to provide support for marketing emails |
| 3.0.26 | 09/25/2020 | Expose actual shipping and fulfillment costs in the order summary object |
| 3.0.25 | 09/16/2020 | New method: OrderApi.adjustOrderTotal |
| 3.0.24 | 09/10/2020 | Bugfix: incorrect response type on CheckoutAPI.registerAffiliateClick |
| 3.0.23 | 09/02/2020 | Added flag to email plan object.  allow_tracking_emails |
| 3.0.22 | 09/02/2020 | Order object - added tracking details |
| 3.0.21 | 09/01/2020 | break fix in php sdk due to bad namespace |
| 3.0.20 | 09/01/2020 | Added OrderApi.processPayment method |
| 3.0.19 | 08/28/2020 | Code Library development: added kraken parameters for thumbnail image generation. |
| 3.0.17 | 08/26/2020 | cont. development work on Code Library |
| 3.0.14 | 08/19/2020 | development work on Code Library |
| 3.0.13 | 08/18/2020 | development work on Code Library |
| 3.0.12 | 08/13/2020 | screenshot urls for campaigns and flows (storefront communications) |
| 3.0.11 | 08/12/2020 | Refactoring and development for Code Library (not released yet) |
| 3.0.10 | 08/10/2020 | Method for registering an affliate click via the SDK, found within CheckoutAPI |
| 3.0.8 | 08/05/2020 | stub for code library 'getLibraryFilterValues' for populating drop down lists |
| 3.0.4 | 08/05/2020 | fixed misspell of 'version' in LibraryItem object. |
| 3.0.3 | 08/04/2020 | added description to addToLibrary call to allow for initial description |
| 3.0.2 | 08/03/2020 | added option on email render step config to allow override of subject, added flow/campaign flag to end once customer purchases |
| 3.0.1 | 07/27/2020 | added init_json to storefront communication email objects |
| 3.0.0 | 07/01/2020 | upgraded our swagger-codegen fork to the latest swagger source code. this was a major changes so we jumped version numbers.  please test all code. |

Some changes jump version numbers due to multiple commits for bug fixes, omissions, and errors.
At UltraCart, we eat our own dog food, and we increment the version number for every commit in order
to generate a new javascript npm.  For this reason, version gaps will be found in the change log above.
